==> haskell-hslua-module-path-1.1.1-73-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-3TN4Rh1IBKd2PwQB2LjUjB
key:                  hslua-module-path-1.1.1-3TN4Rh1IBKd2PwQB2LjUjB
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  4f207a8d7d8c2920ce3b33cf9902f80f
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-3TN4Rh1IBKd2PwQB2LjUjB
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.2-AoHPEgJI7FU53jBqBLyzwJ
    hslua-marshalling-2.3.1-ioF10Y7zsM1Vkhsp51ow4
    hslua-packaging-2.3.1-58eSZDB6wun15nTrPiPJrX text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-path-1.1.1-92-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-J2wz5Th8oI26BKRzwjiaOh
key:                  hslua-module-path-1.1.1-J2wz5Th8oI26BKRzwjiaOh
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  09bf0e23cd213d9b34419bb9c7df141b
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-J2wz5Th8oI26BKRzwjiaOh
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.2-JQMgiBnrP8U52dzk17lMrQ
    hslua-marshalling-2.3.1-1gCbRdTXAK0FajTP4EoWq5
    hslua-packaging-2.3.1-43quJ4tUGXt3u0qKn5mWql text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
